dxf_close_subscription

Function dxf_close_subscription 

pub unsafe extern "C" fn dxf_close_subscription(
    subscription: dxf_subscription_t,
) -> ERRORCODE
@ingroup c-api-basic-subscription-functions

@brief Closes a subscription.

@details All the data associated with it will be disposed. As a side-effect, API error is reset.

@param[in] subscription A handle of the subscription to close

@return {@link DXF_SUCCESS} on successful subscription closure or {@link DXF_FAILURE} on error; {@link dxf_get_last_error} can be used to retrieve the error code and description in case of failure;