pub unsafe extern "C" fn dxf_create_subscription_with_flags(
connection: dxf_connection_t,
event_types: c_int,
subscr_flags: dx_event_subscr_flag,
subscription: *mut dxf_subscription_t,
) -> ERRORCODEExpand description
@ingroup c-api-basic-subscription-functions
@brief Creates a subscription with the specified parameters and the subscription flags.
@details
@param[in] connection A handle of a previously created connection which the subscription will be using @param[in] event_types A bitmask of the subscription event types. See {@link dx_event_id_t} and {@link DX_EVENT_BIT_MASK} for information on how to create an event type bitmask @param[in] subscr_flags A bitmask of the subscription event flags. See {@link dx_event_subscr_flag} @param[out] subscription A handle of the created subscription
@return {@link DXF_SUCCESS} on successful subscription creation or {@link DXF_FAILURE} on error;
{@link dxf_get_last_error} can be used to retrieve the error code and description in case of failure;
a handle to newly created subscription is returned via subscription out parameter