pub unsafe extern "C" fn dxf_get_last_error(
error_code: *mut c_int,
error_descr: *mut dxf_const_string_t,
) -> ERRORCODEExpand description
@ingroup c-api-common
@brief Retrieves the last error info.
@details The error is stored on per-thread basis. If the connection termination notifier callback was invoked, then to retrieve the connection’s error code call this function right from the callback function. If an error occurred within the error storage subsystem itself, the function will return DXF_FAILURE.
@param[out] error_code A pointer to the variable where the error code is to be stored @param[out] error_descr A pointer to the variable where the human-friendly error description is to be stored; may be NULL if the text representation of error is not required @return {@link DXF_SUCCESS} on successful error retrieval or {@link DXF_FAILURE} on error; {@link dxf_get_last_error} can be used to retrieve the error code and description in case of failure; @a error_code and @a error_descr are returned as output parameters of this function