dxf_initialize_logger

Function dxf_initialize_logger 

pub unsafe extern "C" fn dxf_initialize_logger(
    file_name: *const c_char,
    rewrite_file: c_int,
    show_timezone_info: c_int,
    verbose: c_int,
) -> ERRORCODE
@ingroup c-api-common

@brief Initializes the internal logger.

@details Various actions and events, including the errors, are being logged throughout the framework. They may be stored into the file.

@param[in] file_name A full path to the file where the log is to be stored @param[in] rewrite_file A flag defining the file open mode; if it’s nonzero then the log file will be rewritten @param[in] show_timezone_info A flag defining the time display option in the log file; if it’s nonzero then the time will be displayed with the timezone suffix @param[in] verbose A flag defining the logging mode; if it’s nonzero then the verbose logging will be enabled

@return {@link DXF_SUCCESS} on successful logger initialization or {@link DXF_FAILURE} on error; {@link dxf_get_last_error} can be used to retrieve the error code and description in case of failure;