dxf_remove_symbol

Function dxf_remove_symbol 

pub unsafe extern "C" fn dxf_remove_symbol(
    subscription: dxf_subscription_t,
    symbol: dxf_const_string_t,
) -> ERRORCODE
@ingroup c-api-symbol-subscription-functions

@brief Removes a single symbol from the subscription.

@details A wildcard symbol “” will remove all symbols: there will be an unsubscription from messages on all current symbols. If there is already a subscription to “” and the @a symbol to remove is not a “*”, then nothing will happen.

@param[in] subscription A handle of the subscription from which a symbol is removed @param[in] symbol The symbol to remove

@return {@link DXF_SUCCESS} if the operation succeed or {@link DXF_FAILURE} if the operation fails. The error code can be obtained using the function {@link dxf_get_last_error}