dxf_set_order_source

Function dxf_set_order_source 

pub unsafe extern "C" fn dxf_set_order_source(
    subscription: dxf_subscription_t,
    source: *const c_char,
) -> ERRORCODE
@ingroup c-api-orders

@brief Clear current sources and add new one to subscription

@details

@warning You must configure order source before {@link dxf_add_symbols}/{@link dxf_add_symbol} call

@param[in] subscription A handle of the subscription where source will be changed @param[in] source Source of order to set, 4 symbols maximum length

@return {@link DXF_SUCCESS} on order source setup or {@link DXF_FAILURE} on error; {@link dxf_get_last_error} can be used to retrieve the error code and description in case of failure;