pub unsafe extern "C" fn dxf_write_raw_data(
connection: dxf_connection_t,
raw_file_name: *const c_char,
) -> ERRORCODEExpand description
@ingroup c-api-common
@brief Add dumping of incoming traffic into specific file
@details
@param[in] connection A handle of a previously created connection which the subscription will be using @param[in] raw_file_name Raw data file name