dx_theo_price

Struct dx_theo_price 

#[repr(C)]
pub struct dx_theo_price { pub time: dxf_long_t, pub price: dxf_double_t, pub underlying_price: dxf_double_t, pub delta: dxf_double_t, pub gamma: dxf_double_t, pub dividend: dxf_double_t, pub interest: dxf_double_t, }
@brief Theo price

@details Theo price is a snapshot of the theoretical option price computation that is periodically performed by dxPrice model-free computation. It represents the most recent information that is available about the corresponding values at any given moment of time. The values include first and second order derivative of the price curve by price, so that the real-time theoretical option price can be estimated on real-time changes of the underlying price in the vicinity.

Fields

time: dxf_long_t

Timestamp of this event in milliseconds

price: dxf_double_t

Theoretical option price

underlying_price: dxf_double_t

Underlying price at the time of theo price computation

delta: dxf_double_t

Delta of the theoretical price

gamma: dxf_double_t

Gamma of the theoretical price

dividend: dxf_double_t

Implied simple dividend return of the corresponding option series

interest: dxf_double_t

Implied simple interest return of the corresponding option series