dxf_order_t

Struct dxf_order_t 

#[repr(C)]
pub struct dxf_order_t {
Show 21 fields pub source: [dxf_char_t; 17], pub event_flags: dxf_event_flags_t, pub index: dxf_long_t, pub time: dxf_long_t, pub sequence: dxf_int_t, pub time_nanos: dxf_int_t, pub action: dxf_order_action_t, pub action_time: dxf_long_t, pub order_id: dxf_long_t, pub aux_order_id: dxf_long_t, pub price: dxf_double_t, pub size: dxf_double_t, pub executed_size: dxf_double_t, pub count: dxf_double_t, pub trade_id: dxf_long_t, pub trade_price: dxf_double_t, pub trade_size: dxf_double_t, pub exchange_code: dxf_char_t, pub side: dxf_order_side_t, pub scope: dxf_order_scope_t, pub __bindgen_anon_1: dxf_order_t__bindgen_ty_1,
}
Order

Fields

source: [dxf_char_t; 17]

Source of this order

event_flags: dxf_event_flags_t

Transactional event flags.

index: dxf_long_t

Unique per-symbol index of this order.

time: dxf_long_t

Time of this order. Time is measured in milliseconds between the current time and midnight, January 1, 1970 UTC.

sequence: dxf_int_t

Sequence number of this order to distinguish orders that have the same #time.

time_nanos: dxf_int_t

Microseconds and nanoseconds part of time of this order.

action: dxf_order_action_t

Order action if available, otherwise - dxf_oa_undefined. This field is a part of the FOB (“Full Order Book”) support.

action_time: dxf_long_t

Time of the last \ref dxf_order.action if available, otherwise - 0. This field is a part of the FOB (“Full Order Book”) support.

order_id: dxf_long_t

Contains order ID if available, otherwise - 0. Some actions dxf_oa_trade, dxf_oa_bust have no order since they are not related to any order in Order book.

This field is a part of the FOB (“Full Order Book”) support.

aux_order_id: dxf_long_t

Contains auxiliary order ID if available, otherwise - 0:

  • in dxf_oa_new - ID of the order replaced by this new order
  • in dxf_oa_delete - ID of the order that replaces this deleted order
  • in dxf_oa_partial - ID of the aggressor order
  • in dxf_oa_execute - ID of the aggressor order

This field is a part of the FOB (“Full Order Book”) support.

price: dxf_double_t

Price of this order.

size: dxf_double_t

Size of this order

executed_size: dxf_double_t

Executed size of this order. This field is a part of the FOB (“Full Order Book”) support.

count: dxf_double_t

Number of individual orders in this aggregate order.

trade_id: dxf_long_t

Contains trade (order execution) ID for events containing trade-related action if available, otherwise - 0.

This field is a part of the FOB (“Full Order Book”) support.

trade_price: dxf_double_t

Contains trade price for events containing trade-related action.

This field is a part of the FOB (“Full Order Book”) support.

trade_size: dxf_double_t

Contains trade size for events containing trade-related action.

This field is a part of the FOB (“Full Order Book”) support.

exchange_code: dxf_char_t

Exchange code of this order

side: dxf_order_side_t

Side of this order

scope: dxf_order_scope_t

Scope of this order

__bindgen_anon_1: dxf_order_t__bindgen_ty_1