dxf_profile

Struct dxf_profile 

#[repr(C)]
pub struct dxf_profile {
Show 18 fields pub beta: dxf_double_t, pub eps: dxf_double_t, pub div_freq: dxf_double_t, pub exd_div_amount: dxf_double_t, pub exd_div_date: dxf_dayid_t, pub high_52_week_price: dxf_double_t, pub low_52_week_price: dxf_double_t, pub shares: dxf_double_t, pub free_float: dxf_double_t, pub high_limit_price: dxf_double_t, pub low_limit_price: dxf_double_t, pub halt_start_time: dxf_long_t, pub halt_end_time: dxf_long_t, pub raw_flags: dxf_int_t, pub description: dxf_const_string_t, pub status_reason: dxf_const_string_t, pub trading_status: dxf_trading_status_t, pub ssr: dxf_short_sale_restriction_t,
}
@brief Profile

@details Profile information snapshot that contains security instrument description. It represents the most recent information that is available about the traded security on the market at any given moment of time.

Fields

beta: dxf_double_t

The correlation coefficient of the instrument to the S&P500 index (calculated, or received from other data providers)

eps: dxf_double_t

Earnings per share (the company’s profits divided by the number of shares). The value comes directly from the annual quarterly accounting reports of companies. Available generally for stocks

div_freq: dxf_double_t

Frequency of cash dividends payments per year (calculated)

exd_div_amount: dxf_double_t

The amount of the last paid dividend

exd_div_date: dxf_dayid_t

Date of the last dividend payment

high_52_week_price: dxf_double_t

Maximal (high) price in last 52 weeks

low_52_week_price: dxf_double_t

Minimal (low) price in last 52 weeks

shares: dxf_double_t

Shares outstanding. In general, this is the total number of shares issued by this company (only for stocks)

free_float: dxf_double_t

The number of shares outstanding that are available to the public for trade. This field always has NaN value.

high_limit_price: dxf_double_t

Maximal (high) allowed price

low_limit_price: dxf_double_t

Minimal (low) allowed price

halt_start_time: dxf_long_t

Starting time of the trading halt interval

halt_end_time: dxf_long_t

Ending time of the trading halt interval

raw_flags: dxf_int_t

This field contains several individual flags encoded as an integer number the following way:

31...43210
SSRStatus
  1. SSR (shortSaleRestriction) - special mode of protection against “shorting the market”, this field is optional. #dxf_short_sale_restriction_t
  2. Status (tradingStatus) - the state of the instrument. #dxf_trading_status_t
description: dxf_const_string_t

Description of the security instrument

status_reason: dxf_const_string_t

Description of the reason that trading was halted

trading_status: dxf_trading_status_t

Trading status of the security instrument

ssr: dxf_short_sale_restriction_t

Short sale restriction of the security instrument