dxf_quote_t

Struct dxf_quote_t 

#[repr(C)]
pub struct dxf_quote_t { pub time: dxf_long_t, pub sequence: dxf_int_t, pub time_nanos: dxf_int_t, pub bid_time: dxf_long_t, pub bid_exchange_code: dxf_char_t, pub bid_price: dxf_double_t, pub bid_size: dxf_double_t, pub ask_time: dxf_long_t, pub ask_exchange_code: dxf_char_t, pub ask_price: dxf_double_t, pub ask_size: dxf_double_t, pub scope: dxf_order_scope_t, }
@brief Quote.

@details Quote event is a snapshot of the best bid and ask prices, and other fields that change with each quote. It represents the most recent information that is available about the best quote on the market at any given moment of time.

Fields

time: dxf_long_t

Time of the last bid or ask change

sequence: dxf_int_t

Sequence number of this quote to distinguish quotes that have the same #time.

time_nanos: dxf_int_t

Microseconds and nanoseconds part of time of the last bid or ask change

bid_time: dxf_long_t

Time of the last bid change

bid_exchange_code: dxf_char_t

Bid exchange code

bid_price: dxf_double_t

Bid price

bid_size: dxf_double_t

Bid size

ask_time: dxf_long_t

Time of the last ask change

ask_exchange_code: dxf_char_t

Ask exchange code

ask_price: dxf_double_t

Ask price

ask_size: dxf_double_t

Ask size

scope: dxf_order_scope_t

Scope of this quote.

Possible values: #dxf_osc_composite (Quote events) , #dxf_osc_regional (Quote& events)