#[repr(C)]
pub struct dxf_summary {
Show 14 fields pub day_id: dxf_dayid_t, pub day_open_price: dxf_double_t, pub day_high_price: dxf_double_t, pub day_low_price: dxf_double_t, pub day_close_price: dxf_double_t, pub prev_day_id: dxf_dayid_t, pub prev_day_close_price: dxf_double_t, pub prev_day_volume: dxf_double_t, pub open_interest: dxf_double_t, pub raw_flags: dxf_int_t, pub exchange_code: dxf_char_t, pub day_close_price_type: dxf_price_type_t, pub prev_day_close_price_type: dxf_price_type_t, pub scope: dxf_order_scope_t,
}
@brief Summary

@details Summary information snapshot about the trading session including session highs, lows, etc. It represents the most recent information that is available about the trading session in the market at any given moment of time.

Fields

day_id: dxf_dayid_t

Identifier of the day that this summary represents. Identifier of the day is the number of days passed since January 1, 1970.

day_open_price: dxf_double_t

The first (open) price for the day.

day_high_price: dxf_double_t

The maximal (high) price for the day

day_low_price: dxf_double_t

The minimal (low) price for the day

day_close_price: dxf_double_t

The last (close) price for the day

prev_day_id: dxf_dayid_t

Identifier of the previous day that this summary represents. Identifier of the day is the number of days passed since January 1, 1970.

prev_day_close_price: dxf_double_t

The last (close) price for the previous day

prev_day_volume: dxf_double_t

Total volume traded for the previous day

open_interest: dxf_double_t

Open interest of the symbol as the number of open contracts

raw_flags: dxf_int_t

This field contains several individual flags encoded as an integer number the following way:

31...43210
ClosePrevClose
  1. Close (dayClosePriceType) - parameter that shows if the closing price is final #dxf_price_type_t
  2. PrevClose (prevDayClosePriceType) - parameter that shows if the closing price of the previous day is final #dxf_price_type_t
exchange_code: dxf_char_t

Exchange code

day_close_price_type: dxf_price_type_t

The price type of the last (close) price for the day

prev_day_close_price_type: dxf_price_type_t

The price type of the last (close) price for the previous day

scope: dxf_order_scope_t

Scope of this summary.

Possible values: #dxf_osc_composite (Summary events) , #dxf_osc_regional (Summary& events)