dxf_series_t

Type Alias dxf_series_t 

pub type dxf_series_t = dxf_series;
@brief Series

@details Series event is a snapshot of computed values that are available for all option series for a given underlying symbol based on the option prices on the market. It represents the most recent information that is available about the corresponding values on the market at any given moment of time.

Aliased Type

#[repr(C)]
pub struct dxf_series_t {
Show 13 fields pub event_flags: u32, pub index: i64, pub time: i64, pub sequence: i32, pub expiration: i32, pub volatility: f64, pub call_volume: f64, pub put_volume: f64, pub option_volume: f64, pub put_call_ratio: f64, pub forward_price: f64, pub dividend: f64, pub interest: f64,
}

Fields

event_flags: u32

Transactional event flags

index: i64

Unique per-symbol index of this series

time: i64

Time of this series

sequence: i32

Sequence number of this series; distinguishes candles with same #times

expiration: i32

Day id of expiration

volatility: f64

Implied volatility index for this series based on VIX methodology

call_volume: f64

Call options traded volume for a day

put_volume: f64

Put options traded volume for a day

option_volume: f64

Options traded volume for a day

put_call_ratio: f64

Ratio of put options traded volume to call options traded volume for a day

forward_price: f64

Implied forward price for this option series

dividend: f64

Implied simple dividend return of the corresponding option series

interest: f64

Implied simple interest return of the corresponding option series