dxf_summary_t

Type Alias dxf_summary_t 

pub type dxf_summary_t = dxf_summary;
@brief Summary

@details Summary information snapshot about the trading session including session highs, lows, etc. It represents the most recent information that is available about the trading session in the market at any given moment of time.

Aliased Type

#[repr(C)]
pub struct dxf_summary_t {
Show 14 fields pub day_id: i32, pub day_open_price: f64, pub day_high_price: f64, pub day_low_price: f64, pub day_close_price: f64, pub prev_day_id: i32, pub prev_day_close_price: f64, pub prev_day_volume: f64, pub open_interest: f64, pub raw_flags: i32, pub exchange_code: i32, pub day_close_price_type: u32, pub prev_day_close_price_type: u32, pub scope: u32,
}

Fields

day_id: i32

Identifier of the day that this summary represents. Identifier of the day is the number of days passed since January 1, 1970.

day_open_price: f64

The first (open) price for the day.

day_high_price: f64

The maximal (high) price for the day

day_low_price: f64

The minimal (low) price for the day

day_close_price: f64

The last (close) price for the day

prev_day_id: i32

Identifier of the previous day that this summary represents. Identifier of the day is the number of days passed since January 1, 1970.

prev_day_close_price: f64

The last (close) price for the previous day

prev_day_volume: f64

Total volume traded for the previous day

open_interest: f64

Open interest of the symbol as the number of open contracts

raw_flags: i32

This field contains several individual flags encoded as an integer number the following way:

31...43210
ClosePrevClose
  1. Close (dayClosePriceType) - parameter that shows if the closing price is final #dxf_price_type_t
  2. PrevClose (prevDayClosePriceType) - parameter that shows if the closing price of the previous day is final #dxf_price_type_t
exchange_code: i32

Exchange code

day_close_price_type: u32

The price type of the last (close) price for the day

prev_day_close_price_type: u32

The price type of the last (close) price for the previous day

scope: u32

Scope of this summary.

Possible values: #dxf_osc_composite (Summary events) , #dxf_osc_regional (Summary& events)