dxf_underlying_t

Type Alias dxf_underlying_t 

pub type dxf_underlying_t = dxf_underlying;
@brief Underlying

@details Underlying event is a snapshot of computed values that are available for an option underlying symbol based on the option prices on the market. It represents the most recent information that is available about the corresponding values on the market at any given moment of time.

Aliased Type

#[repr(C)]
pub struct dxf_underlying_t { pub volatility: f64, pub front_volatility: f64, pub back_volatility: f64, pub call_volume: f64, pub put_volume: f64, pub option_volume: f64, pub put_call_ratio: f64, }

Fields

volatility: f64

30-day implied volatility for this underlying based on VIX methodology

front_volatility: f64

Front month implied volatility for this underlying based on VIX methodology;

back_volatility: f64

Back month implied volatility for this underlying based on VIX methodology

call_volume: f64

Call options traded volume for a day

put_volume: f64

Put options traded volume for a day

option_volume: f64

Options traded volume for a day

put_call_ratio: f64

Ratio of put options traded volume to call options traded volume for a day