Function libdxfeed_sys::dxf_create_connection_auth_custom
source · pub unsafe extern "C" fn dxf_create_connection_auth_custom(
address: *const c_char,
authscheme: *const c_char,
authdata: *const c_char,
notifier: dxf_conn_termination_notifier_t,
conn_status_notifier: dxf_conn_status_notifier_t,
stcn: dxf_socket_thread_creation_notifier_t,
stdn: dxf_socket_thread_destruction_notifier_t,
user_data: *mut c_void,
connection: *mut dxf_connection_t
) -> ERRORCODEExpand description
@ingroup c-api-connection-functions
@brief Creates connection with the specified parameters and custom described authorization.
@details
@param[in] address Connection string
- the single address: host:port or just host
- address with credentials: host:port[username=xxx,password=yyy]
- multiple addresses:
(host1:port1)(host2)(host3:port3[username=xxx,password=yyy])
- the data from file: /path/to/file on *nix and drive:\path\to\file
on Windows
@param[in] authscheme The authorization scheme
@param[in] authdata The authorization data
@param[in] notifier The callback to inform the client side that the connection has stumbled upon and
error and will go reconnecting
@param[in] conn_status_notifier The callback to inform the client side that the connection status has changed
@param[in] stcn The callback for informing the client side about the socket thread creation;
may be set to NULL if no specific action is required to perform on the client side
on a new thread creation
@param[in] stdn The callback for informing the client side about the socket thread destruction;
may be set to NULL if no specific action is required to perform on the client side
on a thread destruction;
@param[in] user_data The user defined value passed to the termination notifier callback along with the
connection handle; may be set to whatever value;
@param[out] connection The handle of the created connection.
@return {@link DXF_SUCCESS} on successful connection establishment or {@link DXF_FAILURE} on error; created connection is returned via OUT parameter connection; {@link dxf_get_last_error} can be used to retrieve the error code and description in case of failure.
@warning The authscheme and authdata from argument have a higher priority than address credentials.