pub unsafe extern "C" fn dxf_create_snapshot(
connection: dxf_connection_t,
event_id: dx_event_id_t,
symbol: dxf_const_string_t,
source: *const c_char,
time: dxf_long_t,
snapshot: *mut dxf_snapshot_t,
) -> ERRORCODEExpand description
@ingroup c-api-snapshots
@brief Creates snapshot with the specified parameters.
@details For Order or Candle events (dx_eid_order or dx_eid_candle) please use short form of this function: dxf_create_order_snapshot or dxf_create_candle_snapshot respectively.
For order events (event_id is 'dx_eid_order')
If source is NULL string subscription on Order event will be performed. You can specify order
source for Order event by passing suffix: "BYX", "BZX", "DEA", "DEX", "ISE", "IST", "NTV" etc.
If source is equal to "AGGREGATE_BID" or "AGGREGATE_ASK" subscription on MarketMaker event will
be performed. For other events source parameter does not matter.@param[in] connection A handle of a previously created connection which the subscription will be using @param[in] event_id Single event id. Next events is supported: dxf_eid_order, dxf_eid_candle, dx_eid_spread_order, dx_eid_time_and_sale, dx_eid_greeks, dx_eid_series. @param[in] symbol The symbol to add. @param[in] source Order source for Order, which can be one of following: “NTV”, “ntv”, “NFX”, “ESPD”, “XNFI”, “ICE”, “ISE”, “DEA”, “DEX”, “BYX”, “BZX”, “BATE”, “CHIX”, “CEUX”, “BXTR”, “IST”, “BI20”, “ABE”, “FAIR”, “GLBX”, “glbx”, “ERIS”, “XEUR”, “xeur”, “CFE”, “C2OX”, “SMFE”, “smfe”, “iex”, “MEMX”, “memx”. For MarketMaker subscription use “AGGREGATE_BID” or “AGGREGATE_ASK” keyword. @param[in] time Time in the past (unix time in milliseconds). @param[out] snapshot A handle of the created snapshot
@return {@link DXF_SUCCESS} if snapshot has been successfully created or {@link DXF_FAILURE} on error;
{@link dxf_get_last_error} can be used to retrieve the error code and description in case of failure;
newly created snapshot is return via snapshot output parameter