#[repr(C)]pub struct dxf_greeks {
pub event_flags: dxf_event_flags_t,
pub index: dxf_long_t,
pub time: dxf_long_t,
pub price: dxf_double_t,
pub volatility: dxf_double_t,
pub delta: dxf_double_t,
pub gamma: dxf_double_t,
pub theta: dxf_double_t,
pub rho: dxf_double_t,
pub vega: dxf_double_t,
}Expand description
@brief Greeks @details Greeks event is a snapshot of the option price, Black-Scholes volatility and greeks. It represents the most recent information that is available about the corresponding values on the market at any given moment of time.
Fields
event_flags: dxf_event_flags_tTransactional event flags
index: dxf_long_tUnique per-symbol index of this event
time: dxf_long_tTimestamp of this event in milliseconds
price: dxf_double_tOption market price
volatility: dxf_double_tBlack-Scholes implied volatility of the option
delta: dxf_double_tOption delta
gamma: dxf_double_tOption gamma
theta: dxf_double_tOption theta
rho: dxf_double_tOption rho
vega: dxf_double_tOption vega