#[repr(C)]
pub struct dxf_greeks { pub event_flags: dxf_event_flags_t, pub index: dxf_long_t, pub time: dxf_long_t, pub price: dxf_double_t, pub volatility: dxf_double_t, pub delta: dxf_double_t, pub gamma: dxf_double_t, pub theta: dxf_double_t, pub rho: dxf_double_t, pub vega: dxf_double_t, }
@brief Greeks @details Greeks event is a snapshot of the option price, Black-Scholes volatility and greeks. It represents the most recent information that is available about the corresponding values on the market at any given moment of time.

Fields

event_flags: dxf_event_flags_t

Transactional event flags

index: dxf_long_t

Unique per-symbol index of this event

time: dxf_long_t

Timestamp of this event in milliseconds

price: dxf_double_t

Option market price

volatility: dxf_double_t

Black-Scholes implied volatility of the option

delta: dxf_double_t

Option delta

gamma: dxf_double_t

Option gamma

theta: dxf_double_t

Option theta

rho: dxf_double_t

Option rho

vega: dxf_double_t

Option vega