#[repr(C)]pub struct dxf_quote_t {
pub time: dxf_long_t,
pub sequence: dxf_int_t,
pub time_nanos: dxf_int_t,
pub bid_time: dxf_long_t,
pub bid_exchange_code: dxf_char_t,
pub bid_price: dxf_double_t,
pub bid_size: dxf_double_t,
pub ask_time: dxf_long_t,
pub ask_exchange_code: dxf_char_t,
pub ask_price: dxf_double_t,
pub ask_size: dxf_double_t,
pub scope: dxf_order_scope_t,
}Expand description
@brief Quote.
@details Quote event is a snapshot of the best bid and ask prices, and other fields that change with each quote. It represents the most recent information that is available about the best quote on the market at any given moment of time.
Fields
time: dxf_long_tTime of the last bid or ask change
sequence: dxf_int_tSequence number of this quote to distinguish quotes that have the same #time.
time_nanos: dxf_int_tMicroseconds and nanoseconds part of time of the last bid or ask change
bid_time: dxf_long_tTime of the last bid change
bid_exchange_code: dxf_char_tBid exchange code
bid_price: dxf_double_tBid price
bid_size: dxf_double_tBid size
ask_time: dxf_long_tTime of the last ask change
ask_exchange_code: dxf_char_tAsk exchange code
ask_price: dxf_double_tAsk price
ask_size: dxf_double_tAsk size
scope: dxf_order_scope_tScope of this quote.
Possible values: #dxf_osc_composite (Quote events) , #dxf_osc_regional (Quote& events)