#[repr(C)]pub struct dxf_series {Show 13 fields
pub event_flags: dxf_event_flags_t,
pub index: dxf_long_t,
pub time: dxf_long_t,
pub sequence: dxf_int_t,
pub expiration: dxf_dayid_t,
pub volatility: dxf_double_t,
pub call_volume: dxf_double_t,
pub put_volume: dxf_double_t,
pub option_volume: dxf_double_t,
pub put_call_ratio: dxf_double_t,
pub forward_price: dxf_double_t,
pub dividend: dxf_double_t,
pub interest: dxf_double_t,
}Expand description
@brief Series
@details Series event is a snapshot of computed values that are available for all option series for a given underlying symbol based on the option prices on the market. It represents the most recent information that is available about the corresponding values on the market at any given moment of time.
Fields
event_flags: dxf_event_flags_tTransactional event flags
index: dxf_long_tUnique per-symbol index of this series
time: dxf_long_tTime of this series
sequence: dxf_int_tSequence number of this series; distinguishes candles with same #times
expiration: dxf_dayid_tDay id of expiration
volatility: dxf_double_tImplied volatility index for this series based on VIX methodology
call_volume: dxf_double_tCall options traded volume for a day
put_volume: dxf_double_tPut options traded volume for a day
option_volume: dxf_double_tOptions traded volume for a day
put_call_ratio: dxf_double_tRatio of put options traded volume to call options traded volume for a day
forward_price: dxf_double_tImplied forward price for this option series
dividend: dxf_double_tImplied simple dividend return of the corresponding option series
interest: dxf_double_tImplied simple interest return of the corresponding option series