#[repr(C)]pub struct dxf_trade_t {Show 16 fields
pub time: dxf_long_t,
pub sequence: dxf_int_t,
pub time_nanos: dxf_int_t,
pub exchange_code: dxf_char_t,
pub trade_id: dxf_long_t,
pub price: dxf_double_t,
pub size: dxf_double_t,
pub tick: dxf_int_t,
pub change: dxf_double_t,
pub day_id: dxf_dayid_t,
pub day_volume: dxf_double_t,
pub day_turnover: dxf_double_t,
pub raw_flags: dxf_int_t,
pub direction: dxf_direction_t,
pub is_eth: dxf_bool_t,
pub scope: dxf_order_scope_t,
}Expand description
Trade event is a snapshot of the price and size of the last trade during regular trading hours and an overall day volume and day turnover. It represents the most recent information that is available about the regular last trade on the market at any given moment of time.
Fields
time: dxf_long_tTime of the last trade.
sequence: dxf_int_tSequence number of the last trade to distinguish trades that have the same #time.
time_nanos: dxf_int_tMicroseconds and nanoseconds part of time of the last trade
exchange_code: dxf_char_tExchange code of the last trade
trade_id: dxf_long_tTrade id of the last trade
price: dxf_double_tPrice of the last trade
size: dxf_double_tSize of the last trade
tick: dxf_int_tTrend indicator – in which direction price is moving. The values are: Up (Tick = 1), Down (Tick = 2), and Undefined (Tick = 0). Should be used if #direction is Undefined (#dxf_dir_undefined = 0).
This field is absent in TradeETH
change: dxf_double_tChange of the last trade. Value equals price minus dxf_summary_t#prev_day_close_price
day_id: dxf_dayid_tIdentifier of the day that this trade or trade_eth represents. Identifier of the day is the number of days passed since
January 1, 1970.
day_volume: dxf_double_tTotal volume traded for a day
day_turnover: dxf_double_tTotal turnover traded for a day
raw_flags: dxf_int_tThis field contains several individual flags encoded as an integer number the following way:
| 31...4 | 3 | 2 | 1 | 0 |
|---|---|---|---|---|
| Direction | ETH | |||
- Tick Direction (#dxf_direction_t)
- ETH (extendedTradingHours) - flag that determines current trading session: extended or regular (0 - regular trading hours, 1 - extended trading hours).
direction: dxf_direction_tTick direction of the last trade
is_eth: dxf_bool_tLast trade was in extended trading hours
scope: dxf_order_scope_tLast trade scope.
Possible values: #dxf_osc_composite (Trade events) , #dxf_osc_regional (Trade& events)