#[repr(C)]pub struct dxf_underlying {
pub volatility: dxf_double_t,
pub front_volatility: dxf_double_t,
pub back_volatility: dxf_double_t,
pub call_volume: dxf_double_t,
pub put_volume: dxf_double_t,
pub option_volume: dxf_double_t,
pub put_call_ratio: dxf_double_t,
}Expand description
@brief Underlying
@details Underlying event is a snapshot of computed values that are available for an option underlying symbol based on the option prices on the market. It represents the most recent information that is available about the corresponding values on the market at any given moment of time.
Fields
volatility: dxf_double_t30-day implied volatility for this underlying based on VIX methodology
front_volatility: dxf_double_tFront month implied volatility for this underlying based on VIX methodology;
back_volatility: dxf_double_tBack month implied volatility for this underlying based on VIX methodology
call_volume: dxf_double_tCall options traded volume for a day
put_volume: dxf_double_tPut options traded volume for a day
option_volume: dxf_double_tOptions traded volume for a day
put_call_ratio: dxf_double_tRatio of put options traded volume to call options traded volume for a day