pub type dxf_profile_t = dxf_profile;Expand description
@brief Profile
@details Profile information snapshot that contains security instrument description. It represents the most recent information that is available about the traded security on the market at any given moment of time.
Aliased Type
#[repr(C)]pub struct dxf_profile_t {Show 18 fields
pub beta: f64,
pub eps: f64,
pub div_freq: f64,
pub exd_div_amount: f64,
pub exd_div_date: i32,
pub high_52_week_price: f64,
pub low_52_week_price: f64,
pub shares: f64,
pub free_float: f64,
pub high_limit_price: f64,
pub low_limit_price: f64,
pub halt_start_time: i64,
pub halt_end_time: i64,
pub raw_flags: i32,
pub description: *const i32,
pub status_reason: *const i32,
pub trading_status: u32,
pub ssr: u32,
}Fields
beta: f64The correlation coefficient of the instrument to the S&P500 index (calculated, or received from other data providers)
eps: f64Earnings per share (the company’s profits divided by the number of shares). The value comes directly from the annual quarterly accounting reports of companies. Available generally for stocks
div_freq: f64Frequency of cash dividends payments per year (calculated)
exd_div_amount: f64The amount of the last paid dividend
exd_div_date: i32Date of the last dividend payment
high_52_week_price: f64Maximal (high) price in last 52 weeks
low_52_week_price: f64Minimal (low) price in last 52 weeks
Shares outstanding. In general, this is the total number of shares issued by this company (only for stocks)
free_float: f64The number of shares outstanding that are available to the public for trade. This field always has NaN value.
high_limit_price: f64Maximal (high) allowed price
low_limit_price: f64Minimal (low) allowed price
halt_start_time: i64Starting time of the trading halt interval
halt_end_time: i64Ending time of the trading halt interval
raw_flags: i32This field contains several individual flags encoded as an integer number the following way:
| 31...4 | 3 | 2 | 1 | 0 |
|---|---|---|---|---|
| SSR | Status | |||
- SSR (shortSaleRestriction) - special mode of protection against “shorting the market”, this field is optional. #dxf_short_sale_restriction_t
- Status (tradingStatus) - the state of the instrument. #dxf_trading_status_t
description: *const i32Description of the security instrument
status_reason: *const i32Description of the reason that trading was halted
trading_status: u32Trading status of the security instrument
ssr: u32Short sale restriction of the security instrument