Type Definition libdxfeed_sys::dxf_profile_t

source ·
pub type dxf_profile_t = dxf_profile;
@brief Profile

@details Profile information snapshot that contains security instrument description. It represents the most recent information that is available about the traded security on the market at any given moment of time.