pub type dxf_series_t = dxf_series;Expand description
@brief Series
@details Series event is a snapshot of computed values that are available for all option series for a given underlying symbol based on the option prices on the market. It represents the most recent information that is available about the corresponding values on the market at any given moment of time.
Aliased Type
#[repr(C)]pub struct dxf_series_t {}Fields
event_flags: u32Transactional event flags
index: i64Unique per-symbol index of this series
time: i64Time of this series
sequence: i32Sequence number of this series; distinguishes candles with same #times
expiration: i32Day id of expiration
volatility: f64Implied volatility index for this series based on VIX methodology
call_volume: f64Call options traded volume for a day
put_volume: f64Put options traded volume for a day
option_volume: f64Options traded volume for a day
put_call_ratio: f64Ratio of put options traded volume to call options traded volume for a day
forward_price: f64Implied forward price for this option series
dividend: f64Implied simple dividend return of the corresponding option series
interest: f64Implied simple interest return of the corresponding option series