Type Definition libdxfeed_sys::dxf_summary_t
source · pub type dxf_summary_t = dxf_summary;Expand description
@brief Summary
@details Summary information snapshot about the trading session including session highs, lows, etc. It represents the most recent information that is available about the trading session in the market at any given moment of time.