Type Definition libdxfeed_sys::dxf_underlying_t
source · pub type dxf_underlying_t = dxf_underlying;Expand description
@brief Underlying
@details Underlying event is a snapshot of computed values that are available for an option underlying symbol based on the option prices on the market. It represents the most recent information that is available about the corresponding values on the market at any given moment of time.